==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/sl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Opombe",
    "You commented" : "Napišete opombo",
    "%1$s commented" : "%1$s napiše opombo",
    "{author} commented" : "{author} vpiše opombo",
    "You commented on %1$s" : "Napišete opombo za %1$s",
    "You commented on {file}" : "Napišete opombo na {file}",
    "%1$s commented on %2$s" : "%1$s napiše opombo na %2$s",
    "{author} commented on {file}" : "{author} napiše opombo na {file}",
    "<strong>Comments</strong> for files" : "<strong>Opombe</strong> za datoteke",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Uporabnik, ki je sicer že izbrisan, vas omeni v opombi k datoteki »{file}«.",
    "{user} mentioned you in a comment on “{file}”" : "{user} vas omeni v opombi na »{file}«",
    "Files app plugin to add comments to files" : "Vstavek programa Datoteke za dodajanje opomb k datotekam",
    "Edit comment" : "Uredi opombo",
    "Delete comment" : "Izbriši opombo",
    "No comments yet, start the conversation!" : "Ni še odzivov, bodite prvi!",
    "Retry" : "Poskusi  znova",
    "_%n unread comment_::_%n unread comments_" : ["%n  neprebrana opomba","%n  neprebrani opombi","%n  neprebrane opombe","%n neprebranih opomb"],
    "_1 new comment_::_{unread} new comments_" : ["{unread} nova opomba","{unread} novi opombi","{unread} nove opombe","{unread} novih opomb"],
    "Comment" : "Opomba",
    "Comment deleted" : "Opomba je izbrisana",
    "New comment …" : "Nova opomba ...",
    "Post" : "Objavi",
    "Cancel" : "Prekliči",
    "[Deleted user]" : "[Izbrisan uporabnik]",
    "More comments …" : "Več opomb ...",
    "Save" : "Shrani",
    "Allowed characters {count} of {max}" : "Dovoljeni znaki: {count} od {max}",
    "Error occurred while retrieving comment with ID {id}" : "Prišlo je do napake med pridobivanjem opombe z ID {id}",
    "Error occurred while updating comment with id {id}" : "Prišlo je do napake med posodabljanjem opombe z oznako {id}",
    "Error occurred while posting comment" : "Prišlo je do napake med objavo opombe"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/sl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Opombe",
    "You commented" : "Napišete opombo",
    "%1$s commented" : "%1$s napiše opombo",
    "{author} commented" : "{author} vpiše opombo",
    "You commented on %1$s" : "Napišete opombo za %1$s",
    "You commented on {file}" : "Napišete opombo na {file}",
    "%1$s commented on %2$s" : "%1$s napiše opombo na %2$s",
    "{author} commented on {file}" : "{author} napiše opombo na {file}",
    "<strong>Comments</strong> for files" : "<strong>Opombe</strong> za datoteke",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Uporabnik, ki je sicer že izbrisan, vas omeni v opombi k datoteki »{file}«.",
    "{user} mentioned you in a comment on “{file}”" : "{user} vas omeni v opombi na »{file}«",
    "Files app plugin to add comments to files" : "Vstavek programa Datoteke za dodajanje opomb k datotekam",
    "Edit comment" : "Uredi opombo",
    "Delete comment" : "Izbriši opombo",
    "Cancel edit" : "Prekliči urejanje",
    "Post comment" : "Objavi opombo",
    "No comments yet, start the conversation!" : "Ni še odzivov, bodite prvi!",
    "No more messages" : "Ni drugih sporočil",
    "Retry" : "Poskusi znova",
    "Unable to load the comments list" : "Ni mogoče naložiti seznama opomb",
    "_%n unread comment_::_%n unread comments_" : ["%n  neprebrana opomba","%n  neprebrani opombi","%n  neprebrane opombe","%n neprebranih opomb"],
    "_1 new comment_::_{unread} new comments_" : ["{unread} nova opomba","{unread} novi opombi","{unread} nove opombe","{unread} novih opomb"],
    "Comment" : "Opomba",
    "An error occurred while trying to edit the comment" : "Prišlo je do napake med poskusom urejanja opombe",
    "Comment deleted" : "Opomba je izbrisana",
    "An error occurred while trying to delete the comment" : "Prišlo je do napake med brisanjem opombe",
    "An error occurred while trying to create the comment" : "Prišlo je do napake med ustvarjanjem opombe",
    "New comment …" : "Nova opomba ...",
    "Post" : "Objavi",
    "Cancel" : "Prekliči",
    "[Deleted user]" : "[Izbrisan uporabnik]",
    "More comments …" : "Več opomb ...",
    "Save" : "Shrani",
    "Allowed characters {count} of {max}" : "Dovoljeni znaki: {count} od {max}",
    "Error occurred while retrieving comment with ID {id}" : "Prišlo je do napake med pridobivanjem opombe z ID {id}",
    "Error occurred while updating comment with id {id}" : "Prišlo je do napake med posodabljanjem opombe z oznako {id}",
    "Error occurred while posting comment" : "Prišlo je do napake med objavo opombe"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
